@@ -16,7 +16,7 @@ use constant INFINITY     =>       100 ** 100 ** 100 ;
 use constant NEG_INFINITY => -1 * (100 ** 100 ** 100);
 
 BEGIN {
-    $VERSION = '0.26';
+    $VERSION = '0.29';
 }
 
 
@@ -298,6 +298,11 @@ sub empty_set {
     return bless { set => Set::Infinite::_recurrence->new }, $class;
 }
 
+sub is_empty_set {
+    my $set = $_[0];
+    $set->{set}->is_null;
+}
+
 sub clone { 
     my $self = bless { %{ $_[0] } }, ref $_[0];
     $self->{set} = $_[0]->{set}->copy;
@@ -488,7 +493,6 @@ sub closest {
     return $dt2;
 }
 
-
 sub as_list {
     my $self = shift;
     return undef unless ref( $self->{set} );
@@ -511,16 +515,22 @@ sub as_list {
            $set->min->is_infinite;
 
     my @result;
-    # we should extract _copies_ of the set elements,
-    # such that the user can't modify the set indirectly
-
-    my $iter = $set->iterator;
-    while ( my $dt = $iter->next ) 
-    {
-        push @result, $dt
-            if ref( $dt );   # we don't want to return INFINITY value
-    };
-
+    my $next = $self->min;
+    if ( $span ) {
+        my $next1 = $span->min;
+        $next = $next1 if $next1 && $next1 > $next;
+        $next = $self->current( $next );
+    }
+    my $last = $self->max;
+    if ( $span ) {
+        my $last1 = $span->max;
+        $last = $last1 if $last1 && $last1 < $last;
+    }
+    do {
+        push @result, $next if !$span || $span->contains($next);
+        $next = $self->next( $next );
+    }
+    while $next && $next <= $last;
     return @result;
 }
 
@@ -839,6 +849,12 @@ Creates a new empty set.
     $set = DateTime::Set->empty_set;
     print "empty set" unless defined $set->max;
 
+=item * is_empty_set
+
+Returns true is the set is empty; false otherwise.
+
+    print "nothing" if $set->is_empty_set;
+
 =item * clone
 
 This object method returns a replica of the given object.
