@@ -150,6 +150,11 @@ sub new {
     return $class->from_datetimes(%args);
 }
 
+sub is_empty_set {
+    my $set = $_[0];
+    $set->{set}->is_null;
+}
+
 sub clone { 
     bless { 
         set => $_[0]->{set}->copy,
@@ -286,11 +291,11 @@ sub span { @_ }
 sub duration { 
     my $dur;
 
+    local $@;
     eval {
         local $SIG{__DIE__};   # don't want to trap this (rt ticket 5434)
         $dur = $_[0]->end->subtract_datetime_absolute( $_[0]->start )
     };
-    $@ = undef;  # clear the eval() error message
     
     return $dur if defined $dur;
 
